@@ -3,17 +3,17 @@ library(locfit)
 
 test_that("lp_model works with linelisting data", {
   df <- hav_be_2002[order(hav_be_2002$age),]
+  df$status <- df$seropositive
 
-  expect_no_error(lp_model(df$age, status = df$seropositive))
+  expect_no_error(lp_model(df))
 })
 
 test_that("lp_model returns expected results", {
   expected_foi_summary <- c(0.0018361, 0.0856287, 0.107952, 0.294777)
   expected_sp_summary <- c(0.165227, 0.968281, 0.884160, 0.985884)
 
-  df <- mumps_uk_1986_1987
   model <- lp_model(
-      df$age, pos = df$pos, tot = df$tot,
+    mumps_uk_1986_1987,
       nn=0.7, kern="tcub"
     )
 
